/*
	dotnetdemo - demonstrates using the Collabrary from a Microsoft.NET Framework language.
	
	This demo shows how to do a lot of things, but if one actually wanted to do any of them,
	this probably wouldn't be the way to do it.
	
	Demonstrates capturing video from a Camera, streaming it through a SharedDictionary,
	and moving between Collabrary.Photo and System.Drawing.Bitmap.
*/

using System;
using System.Collections;
using System.Drawing;
using System.Drawing.Imaging;
using System.Resources;
using System.Windows.Forms;
using Collabrary;

namespace dotnetdemo
{
	class MainForm : Form
	{
		public static void Main(string[] args)
		{
			Application.Run(new MainForm());
		}
		public static System.Drawing.Bitmap PhotoToBitmap(Collabrary.Photo p)
		{
			return System.Drawing.Bitmap.FromHbitmap(p.Hbitmap);
		}
		public static Collabrary.Photo BitmapToPhoto(System.Drawing.Bitmap b)
		{
			System.Drawing.Imaging.BitmapData bd = b.LockBits(new Rectangle(0, 0, b.Width, b.Height), System.Drawing.Imaging.ImageLockMode.ReadOnly, System.Drawing.Imaging.PixelFormat.Format24bppRgb);
			Collabrary.Photo p = new Collabrary.PhotoClass();
			p.Resize(bd.Width, bd.Height, false);
			p.PasteBitmapData(((int) bd.Scan0), bd.Width, bd.Height, bd.Stride);
			b.UnlockBits(bd);
			return p;
		}

		ResourceManager res = new ResourceManager(typeof(MainForm));
		Collabrary.Photo azul;
		Collabrary.Camera cam;
		Collabrary.SharedDictionary sd;
		Collabrary.Subscription subscr;
		Image Image;
		
		MainForm() : base()
		{
			//
			// MainForm
			//
			this.Name = res.GetString("$this.Name");
			this.Icon = ((Icon) res.GetObject("$this.Icon"));
			this.Text = "Collabrary.NET Demo";
			this.SetStyle(ControlStyles.AllPaintingInWmPaint|ControlStyles.UserPaint|ControlStyles.DoubleBuffer, true);
		}
		
		protected override void OnLoad(EventArgs e)
		{
			this.azul = BitmapToPhoto(((Bitmap) res.GetObject("$this.Image")));
			this.azul.Resize(320, 240, false);
			this.cam = new CameraClass();
			this.cam.Captured += new CameraEvents_CapturedEventHandler(this.cam_Captured);
			this.sd = new SharedDictionaryClass();
			this.subscr = this.sd.Subscribe("/f");
			this.subscr.Notified += new SubscriptionEvents_NotifiedEventHandler(this.subscr_Notified);
			this.cam.Size = CameraSizeStyle.s320x240;
			this.cam.FrameRate = 18;
		}		

		protected override void OnClosed(EventArgs e)
		{
			this.cam.FrameRate = 0;
			this.cam = null;
			this.sd = null;
			this.subscr = null;
		}
		
		private void cam_Captured(Collabrary.IPhoto frame)
		{
			this.sd["/f"] = frame;
		}
		
		private void subscr_Notified(string key, string instance, object val, SubscriptionNotifyStyle reason, object prev)
		{
			Photo p = ((Photo) val);
			p.Paste(this.azul, 0, 0, 0.5f);
			this.Image = PhotoToBitmap(p);
			this.Refresh();
		}
		
		protected override void OnPaint(PaintEventArgs e)
		{
			base.OnPaint(e);
			if(null != this.Image)
			{
				e.Graphics.DrawImage(this.Image, 0, 0);
			}
		}
	}
}
