/*
    mkres - Microsoft .NET Framework Resource File Generator
    Copyright (C) 2003  Michael Boyle

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
using System;
using System.Drawing;
using System.IO;
using System.Reflection;
using System.Resources;
using System.Windows.Forms;

[assembly:AssemblyTitle("mkres"),AssemblyDescription("Microsoft.NET Framework Resource File Generator")]
namespace mkres
{
	public class MainClass
	{
		public static void Main(string[] args)
		{
			if(0 == args.Length)
			{
				Console.WriteLine("Microsoft .NET Framework Resource File Generator\nsyntax: mkres filename.{resources|resX} resources...\nSupported resources:\n\t/icon ResName FileName\n\t/image ResName FileName\n\t/cursor ResName FileName\n\t/string ResName \"string\"\n\t/filestring ResName FileName\n\t/filebytes ResName FileName\n\t/imagelist ResName FileName FileName FileName...");
				return;
			}
			IResourceWriter rw;
			switch(Path.GetExtension(args[0]).ToLower())
			{
				case ".resources":
					rw = new ResourceWriter(args[0]);
					break;
				case ".resx":
					rw = new ResXResourceWriter(args[0]);
					break;
				default:
					throw new ArgumentException(String.Format("Unknown file type: {0}", args[0]));
			}
			for(int i = 1; i < args.Length;)
			{
				switch(args[i].ToLower())
				{
					default:
						throw new ArgumentException(args[i]);
					case "/icon":
						rw.AddResource(args[i+1], new Icon(args[i + 2]));
						i += 3;
						break;
					case "/image":
						rw.AddResource(args[i + 1], Image.FromFile(args[i + 2]));
						i += 3;
						break;
					case "/cursor":
						rw.AddResource(args[i + 1], new Cursor(args[i + 2]));
						i += 3;
						break;
					case "/string":
						rw.AddResource(args[i + 1], args[i + 2]);
						i += 3;
						break;
					case "/filestring":
						using(StreamReader sr = new StreamReader(args[i + 2]))
						{
							rw.AddResource(args[i + 1], sr.ReadToEnd());
						}
						i += 3;
						break;
					case "/filebytes":
						using(FileStream fs = new FileStream(args[i + 2], FileMode.Open))
						{
							byte[] arr = new byte[fs.Length];
							fs.Read(arr, 0, arr.Length);
							rw.AddResource(args[i + 1], arr);
						}
						i += 3;
						break;
					case "/imagelist":
						using(ImageList il = new ImageList())
						{
							string resname = args[i + 1];
							for(i+=2; (i < args.Length) && ('/' != args[i][0]); i++)
							{
								switch(Path.GetExtension(args[i]).ToLower())
								{
									default:
										il.Images.Add(Image.FromFile(args[i]));
										break;
									case ".ico":
										il.Images.Add(new Icon(args[i]));
										break;
								}
							}
							rw.AddResource(resname, il.ImageStream);
						}
						break;
				}
			}
			rw.Close();			
		}
	}
}
